@@ -1,40 +1,16 @@
 import os
 import json
 import uuid
-
-import logging
-from logging.config import dictConfig
-
 import munch
 from werkzeug.serving import run_simple
 from werkzeug.wrappers import Request, Response
 from werkzeug.exceptions import HTTPException, NotFound
 from werkzeug.routing import Map, Rule
+from ashes import AshesEnv
 
-__version__ = '0.1.1'
 
 apiname = os.environ.get('SOLACE_API_NAME', str(uuid.uuid4()))
 
-
-DEFAULT_LOGGING = {
-    'version': 1,
-    'disable_existing_loggers': False,
-    'loggers': {
-        '': {
-            'level': os.environ.get('LOG_LEVEL', 'WARNING').upper(),
-        }
-    }
-}
-logging.config.dictConfig(DEFAULT_LOGGING)
-
-# try:
-#     log_level = os.environ['LOG_LEVEL'].upper()
-# except KeyError:
-#     log_level = "WARNING"
-#     log.warning("optional environment variable LOG_LEVEL was not set")
-# log.setLevel(logging.getLevelName(log_level))
-# log.warning("log level is set to {}".format(log_level))
-
 # TODO: catch any errors that may come from not passing the proper data type here
 # TODO: raise our own custom error types
 def objectify(dict):
@@ -42,13 +18,20 @@ def objectify(dict):
 
 class SolaceResponse(Response):
     json = munch.munchify({})
+    html = None
 
-    def __init__(self,):
+    def __init__(self, config = {}):
         super().__init__()
+        self.config = config
+        self.tplenv = AshesEnv([self.config.get("templates_dir", "src/templates")])
 
-class Api:
+    def tpl(self, template, context = {}):
+        self.html = self.tplenv.render(template, context)
+
+class Solace:
     
-    def __init__(self):
+    def __init__(self, config = {}):
+        self.config = {}
         self.rules = Map([])
         self.views = {}
     
@@ -126,14 +109,7 @@ class Api:
         to a resource.
         """
         self.__rule('PATCH', urlpath, handler)
-    
-    def websocket(self, urlpath, handler):
-        # NOTE: Werkzeug has no further WebSocket support beyond routing.
-        # TODO: We'll need to bring in a Websocket library and support
-        # events, and socket management.
-        """
-        """
-    
+
     def register(self, Middleware):
         pass
 
@@ -154,6 +130,13 @@ class Api:
             if self.res.json:
                 self.res.content_type = "application/json"
                 self.res.data = json.dumps(self.res.json)
+                return self.res
+
+            if self.res.html:
+                self.res.content_type = "text/html"
+                self.res.data = self.res.html
+                return self.res
+
             return self.res
         except HTTPException as e:
             err = {
@@ -178,8 +161,8 @@ class DevelopmentServer:
     # that we can support for the DevelopmentServer.
     # https://werkzeug.palletsprojects.com/en/2.0.x/serving/
 
-    def __init__(self, api, host = "127.0.0.1", port = 5000, reload = True):
-        self.api = api
+    def __init__(self, app, host = "127.0.0.1", port = 5000, reload = True):
+        self.app = app
         self.host = host
         self.port = port
         self.reload = reload
@@ -188,7 +171,7 @@ class DevelopmentServer:
         run_simple(
             self.host, 
             self.port, 
-            self.api, 
+            self.app, 
             use_debugger=False,
             use_reloader=self.reload
         )
